durtools.yield_all_positive_integer_pairs_in_cantor_diagonalized_order
======================================================================

.. autofunction:: abjad.tools.durtools.yield_all_positive_integer_pairs_in_cantor_diagonalized_order
